@@ -30,8 +30,9 @@
 #include <QDBusInterface>
 #include <QMessageBox>
 #include <QApplication>
-#include <QDesktopWidget>
 #include <QtDebug>
+#include <QScreen>
+#include <QFile>
 #include "lxqttranslator.h"
 #include "lxqtglobals.h"
 #include "lxqtsettings.h"
@@ -44,7 +45,7 @@ class LXQT_API MessageBox: public QMessageBox
     Q_DECLARE_TR_FUNCTIONS(LXQt::MessageBox)
 
 public:
-    explicit MessageBox(QWidget *parent = 0): QMessageBox(parent) {}
+    explicit MessageBox(QWidget *parent = nullptr): QMessageBox(parent) {}
 
     static QWidget *parentWidget()
     {
@@ -53,7 +54,7 @@ public:
         if (widgets.count())
             return widgets.at(0);
         else
-            return 0;
+            return nullptr;
     }
 
     static bool question(const QString& title, const QString& text)
@@ -62,6 +63,7 @@ public:
         msgBox.setWindowTitle(title);
         msgBox.setText(text);
         msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
+        msgBox.setDefaultButton(QMessageBox::Yes);
 
         return (msgBox.exec() == QMessageBox::Yes);
     }
@@ -76,10 +78,11 @@ public:
 
 
 protected:
-    virtual void resizeEvent(QResizeEvent* event)
+    void resizeEvent(QResizeEvent* event) override
     {
         Q_UNUSED(event)
-        const QRect screen = QApplication::desktop()->screenGeometry();
+        const QScreen *primaryScreen = QGuiApplication::primaryScreen();
+        const QRect screen = primaryScreen ? primaryScreen->geometry() : QRect();
         move((screen.width()  - this->width()) / 2,
              (screen.height() - this->height()) / 2);
 
