@@ -28,6 +28,7 @@
  * END_COMMON_COPYRIGHT_HEADER */
 
 #include <QProcess>
+#include <QSettings>
 #include "lxqtscreensaver.h"
 #include "lxqttranslator.h"
 
@@ -101,7 +102,7 @@ static bool GetIntArrayProperty(XID window,
     Atom type = None;
     int format = 0;  // size in bits of each item in 'property'
     unsigned long num_items = 0;
-    unsigned char* properties = NULL;
+    unsigned char* properties = nullptr;
 
     int result = GetProperty(window, property_name,
                            (~0L), // (all of them)
@@ -129,64 +130,68 @@ class ScreenSaverPrivate
     ScreenSaver* const q_ptr;
 
 public:
-    ScreenSaverPrivate(ScreenSaver *q) : q_ptr(q) {};
+    ScreenSaverPrivate(ScreenSaver *q) : q_ptr(q) {
+        QSettings settings(QSettings::UserScope, QLatin1String("lxqt"), QLatin1String("lxqt"));
 
-    void _l_xdgProcess_finished(int, QProcess::ExitStatus);
+        settings.beginGroup(QLatin1String("Screensaver"));
+        lock_command = settings.value(QLatin1String("lock_command"), QLatin1String("xdg-screensaver lock")).toString();
+        settings.endGroup();
+    }
+
+    void reportLockProcessError();
+    void _l_lockProcess_finished(int, QProcess::ExitStatus);
+    void _l_lockProcess_errorOccurred(QProcess::ProcessError);
     bool isScreenSaverLocked();
 
-    QPointer<QProcess> m_xdgProcess;
+    QPointer<QProcess> m_lockProcess;
+
+    QString lock_command;
 };
 
-void ScreenSaverPrivate::_l_xdgProcess_finished(int err, QProcess::ExitStatus status)
+void ScreenSaverPrivate::reportLockProcessError()
 {
-    // http://portland.freedesktop.org/xdg-utils-1.1.0-rc1/scripts/xdg-screensaver
+    QMessageBox box;
+    box.setAttribute(Qt::WA_DeleteOnClose);
+    box.setIcon(QMessageBox::Warning);
+    box.setWindowTitle(tr("Screen Saver Error"));
+    QString message;
+    // contains() instead of startsWith() as the command might be "env FOO=bar xdg-screensaver lock"
+    // (e.g., overwrite $XDG_CURRENT_DESKTOP for some different behaviors)
+    if (lock_command.contains(QLatin1String("xdg-screensaver"))) {
+        message = tr("Failed to run  \"%1\". "
+                     "Ensure you have a locker/screensaver compatible with xdg-screensaver installed and running."
+                    );
+    } else {
+        message = tr("Failed to run  \"%1\". "
+                     "Ensure the specified locker/screensaver is installed and running."
+                    );
+    }
+    box.setText(message.arg(lock_command));
+    box.exec();
+}
 
+void ScreenSaverPrivate::_l_lockProcess_finished(int err, QProcess::ExitStatus status)
+{
     Q_UNUSED(status)
     Q_Q(ScreenSaver);
     if (err == 0)
-        emit q->activated();
+        Q_EMIT q->activated();
     else
     {
-        QMessageBox *box = new QMessageBox;
-        box->setAttribute(Qt::WA_DeleteOnClose);
-        box->setIcon(QMessageBox::Warning);
-
-        if (err == 1)
-        {
-            box->setWindowTitle(tr("Screen Saver Error"));
-            box->setText(tr("An error occurred starting screensaver. "
-                           "Syntax error in xdg-screensaver arguments."));
-        }
-        else if (err == 3)
-        {
-            box->setWindowTitle(tr("Screen Saver Activation Error"));
-            box->setText(tr("An error occurred starting screensaver. "
-                           "Ensure you have xscreensaver installed and running."));
-        }
-        else if (err == 4)
-        {
-            box->setWindowTitle(tr("Screen Saver Activation Error"));
-            box->setText(tr("An error occurred starting screensaver. "
-                           "Action 'activate' failed. "
-                           "Ensure you have xscreensaver installed and running."));
-        }
-        else
-        {
-            box->setWindowTitle(tr("Screen Saver Activation Error"));
-            box->setText(tr("An error occurred starting screensaver. "
-                           "Unknown error - undocumented return value from xdg-screensaver: %1.")
-                        .arg(err));
-        }
-
-        box->exec();
+        reportLockProcessError();
     }
 
-    emit q->done();
+    Q_EMIT q->done();
+}
+
+void ScreenSaverPrivate::_l_lockProcess_errorOccurred(QProcess::ProcessError)
+{
+    reportLockProcessError();
 }
 
 bool ScreenSaverPrivate::isScreenSaverLocked()
 {
-    XScreenSaverInfo *info = 0;
+    XScreenSaverInfo *info = nullptr;
     Display *display = QX11Info::display();
     XID window = DefaultRootWindow(display);
     info = XScreenSaverAllocInfo();
@@ -218,9 +223,11 @@ ScreenSaver::ScreenSaver(QObject * parent)
       d_ptr(new ScreenSaverPrivate(this))
 {
     Q_D(ScreenSaver);
-    d->m_xdgProcess = new QProcess(this);
-    connect(d->m_xdgProcess, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished),
-        [=](int exitCode, QProcess::ExitStatus exitStatus){ d->_l_xdgProcess_finished(exitCode, exitStatus); });
+    d->m_lockProcess = new QProcess(this);
+    connect(d->m_lockProcess, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished),
+        [=](int exitCode, QProcess::ExitStatus exitStatus){ d->_l_lockProcess_finished(exitCode, exitStatus); });
+    connect(d->m_lockProcess, &QProcess::errorOccurred,
+        [=](QProcess::ProcessError error) { d->_l_lockProcess_errorOccurred(error); });
 }
 
 ScreenSaver::~ScreenSaver()
@@ -244,7 +251,7 @@ void ScreenSaver::lockScreen()
 {
     Q_D(ScreenSaver);
     if (!d->isScreenSaverLocked())
-        d->m_xdgProcess->start(QL1S("xdg-screensaver"), QStringList() << QL1S("lock"));
+        d->m_lockProcess->start(d->lock_command);
 }
 
 } // namespace LXQt
