@@ -12,12 +12,12 @@
 <context>
     <name>LXQt::MessageBox</name>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="74"/>
+        <location filename="../lxqtpowermanager.cpp" line="75"/>
         <source>LXQt Power Manager Error</source>
-        <translation>Fehler der LXQt-Energieverwaltung</translation>
+        <translation>LXQt-Energieverwaltung Fehler</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="74"/>
+        <location filename="../lxqtpowermanager.cpp" line="75"/>
         <source>Hibernate failed.</source>
         <translation>Ruhezustand fehlgeschlagen.</translation>
     </message>
@@ -27,99 +27,99 @@
     <message>
         <location filename="../lxqtnotification.cpp" line="154"/>
         <source>Notifications Fallback</source>
-        <translation>Ersatzbenachrichtigung</translation>
+        <translation>Benachrichtigung Fallback</translation>
     </message>
 </context>
 <context>
     <name>LXQt::PowerManager</name>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="117"/>
+        <location filename="../lxqtpowermanager.cpp" line="118"/>
         <source>Hibernate</source>
         <translation>Ruhezustand</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="124"/>
+        <location filename="../lxqtpowermanager.cpp" line="125"/>
         <source>Suspend</source>
         <translation>Bereitschaft</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="131"/>
+        <location filename="../lxqtpowermanager.cpp" line="132"/>
         <source>Reboot</source>
         <translation>Neustart</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="138"/>
+        <location filename="../lxqtpowermanager.cpp" line="139"/>
         <source>Shutdown</source>
         <translation>Herunterfahren</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="145"/>
+        <location filename="../lxqtpowermanager.cpp" line="146"/>
         <source>Logout</source>
         <translation>Abmelden</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="157"/>
+        <location filename="../lxqtpowermanager.cpp" line="158"/>
         <source>LXQt Session Suspend</source>
-        <translation>Bereitschaft der LXQT-Sitzung</translation>
+        <translation>LXQT-Sitzung Bereitschaft</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="158"/>
+        <location filename="../lxqtpowermanager.cpp" line="159"/>
         <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
         <translation>Möchten Sie ihren Computer in Bereitschaft versetzen?&lt;p&gt;Der Computer wird in einen Energiesparmodus versetzt. Der Systemzustand geht verloren, wenn die Energiezufuhr abbricht.</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="167"/>
+        <location filename="../lxqtpowermanager.cpp" line="168"/>
         <source>LXQt Session Hibernate</source>
-        <translation>Ruhezustand der LXQT-Sitzung</translation>
+        <translation>LXQT-Sitzung Ruhezustand</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="168"/>
+        <location filename="../lxqtpowermanager.cpp" line="169"/>
         <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
         <translation>Möchten Sie ihren Computer in Ruhezustand versetzen?&lt;p&gt;Dies versetzt ihren Computer in einen Energiesparmodus. Der Systemzustand bleibt erhalten, wenn die Energiezufuhr abbricht.</translation>
     </message>
-    <message>
-        <location filename="../lxqtpowermanager.cpp" line="177"/>
-        <source>LXQt Session Reboot</source>
-        <translation>Neustart der LXQT-Sitzung</translation>
-    </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="178"/>
-        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
-        <translation>Möchten Sie ihren Computer wirklich neustarten? Alle ungespeicherten Arbeiten gehen verloren...</translation>
+        <source>LXQt Session Reboot</source>
+        <translation>LXQT-Sitzung Neustart</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="187"/>
-        <source>LXQt Session Shutdown</source>
-        <translation>Herunterfahren der LXQT-Sitzung</translation>
+        <location filename="../lxqtpowermanager.cpp" line="179"/>
+        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
+        <translation>Möchten Sie ihren Computer wirklich neustarten? Alle ungespeicherten Arbeiten gehen verloren…</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="188"/>
-        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
-        <translation>Möchten Sie ihren Computer wirklich herunterfahren? Alle ungespeicherten Arbeiten gehen verloren...</translation>
+        <source>LXQt Session Shutdown</source>
+        <translation>LXQT-Sitzung Herunterfahren</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="197"/>
-        <source>LXQt Session Logout</source>
-        <translation>Abmelden der LXQT-Sitzung</translation>
+        <location filename="../lxqtpowermanager.cpp" line="189"/>
+        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
+        <translation>Möchten Sie ihren Computer wirklich herunterfahren? Alle ungespeicherten Arbeiten gehen verloren…</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="198"/>
+        <source>LXQt Session Logout</source>
+        <translation>LXQT-Sitzung Abmelden</translation>
+    </message>
+    <message>
+        <location filename="../lxqtpowermanager.cpp" line="199"/>
         <source>Do you want to really logout? All unsaved work will be lost...</source>
-        <translation>Möchten Sie sich wirklich abmelden? Alle ungespeicherten Arbeiten gehen verloren...</translation>
+        <translation>Möchten Sie sich wirklich abmelden? Alle ungespeicherten Arbeiten gehen verloren…</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="206"/>
-        <location filename="../lxqtpowermanager.cpp" line="211"/>
+        <location filename="../lxqtpowermanager.cpp" line="207"/>
+        <location filename="../lxqtpowermanager.cpp" line="212"/>
         <source>LXQt Power Manager Error</source>
-        <translation>Fehler der LXQt-Energieverwaltung</translation>
+        <translation>LXQt-Energieverwaltung Fehler</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="206"/>
+        <location filename="../lxqtpowermanager.cpp" line="207"/>
         <source>Hibernate failed.</source>
         <translation>Ruhezustand fehlgeschlagen.</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="211"/>
+        <location filename="../lxqtpowermanager.cpp" line="212"/>
         <source>Suspend failed.</source>
         <translation>Bereitschaft fehlgeschlagen.</translation>
     </message>
@@ -127,41 +127,24 @@
 <context>
     <name>LXQt::ScreenSaver</name>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="236"/>
+        <location filename="../lxqtscreensaver.cpp" line="161"/>
+        <source>Failed to run  &quot;%1&quot;. Ensure you have a locker/screensaver compatible with xdg-screensaver installed and running.</source>
+        <translation>Fehler beim Ausführen von &amp;quot;% 1&amp;quot; Stellen Sie sicher, dass Sie einen mit xdg-screensaver kompatiblen Locker/Bildschirmschoner installiert haben.</translation>
+    </message>
+    <message>
+        <location filename="../lxqtscreensaver.cpp" line="165"/>
+        <source>Failed to run  &quot;%1&quot;. Ensure the specified locker/screensaver is installed and running.</source>
+        <translation>Fehler beim Ausführen von &amp;quot;% 1&amp;quot; Stellen Sie sicher, dass der ausgewählte Locker/Bildschirmschoner installiert ist und läuft..</translation>
+    </message>
+    <message>
+        <location filename="../lxqtscreensaver.cpp" line="243"/>
         <source>Lock Screen</source>
         <translation>Bildschirm sperren</translation>
     </message>
     <message>
         <location filename="../lxqtscreensaver.cpp" line="156"/>
         <source>Screen Saver Error</source>
-        <translation>Bildschirmschoner-Fehler</translation>
-    </message>
-    <message>
-        <location filename="../lxqtscreensaver.cpp" line="157"/>
-        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
-        <translation>Beim Starten des Bildschirmschoners ist ein Fehler aufgetreten. Syntaxfehler in den Parametern für xdg-screensaver.</translation>
-    </message>
-    <message>
-        <location filename="../lxqtscreensaver.cpp" line="162"/>
-        <location filename="../lxqtscreensaver.cpp" line="168"/>
-        <location filename="../lxqtscreensaver.cpp" line="175"/>
-        <source>Screen Saver Activation Error</source>
-        <translation>Fehler beim Aktivieren des Bildschirmschoners</translation>
-    </message>
-    <message>
-        <location filename="../lxqtscreensaver.cpp" line="163"/>
-        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
-        <translation>Beim Starten des Bildschirmschoners ist ein Fehler aufgetreten. Bitte stellen Sie sicher, dass xscreensaver installiert ist und funktioniert.</translation>
-    </message>
-    <message>
-        <location filename="../lxqtscreensaver.cpp" line="169"/>
-        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
-        <translation>Beim Starten des Bildschirmschoners ist ein Fehler aufgetreten. Aktion &apos;aktivieren&apos; fehlgeschlagen. Bitte stellen Sie sicher, dass xscreensaver installiert ist und funktioniert.</translation>
-    </message>
-    <message>
-        <location filename="../lxqtscreensaver.cpp" line="176"/>
-        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
-        <translation>Beim Starten des Bildschirmschoners ist ein Fehler aufgetreten. Unbekannter Fehler - ein undokumentierter Rückgabewert wurde von xdg-screensaver ausgegeben: %1.</translation>
+        <translation>Bildschirmschoner Fehler</translation>
     </message>
 </context>
 <context>
@@ -169,7 +152,7 @@
     <message>
         <location filename="../configdialog/lxqtconfigdialogcmdlineoptions.cpp" line="49"/>
         <source>Choose the page to be shown.</source>
-        <translation>Wähle die darzustellende Seite.</translation>
+        <translation>Wählen Sie die anzuzeigende Seite.</translation>
     </message>
 </context>
 <context>
