@@ -12,12 +12,12 @@
 <context>
     <name>LXQt::MessageBox</name>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="74"/>
+        <location filename="../lxqtpowermanager.cpp" line="75"/>
         <source>LXQt Power Manager Error</source>
         <translation>Kesalahan Manajer Daya LXQt</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="74"/>
+        <location filename="../lxqtpowermanager.cpp" line="75"/>
         <source>Hibernate failed.</source>
         <translation>Hibernasi gagal.</translation>
     </message>
@@ -33,93 +33,93 @@
 <context>
     <name>LXQt::PowerManager</name>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="117"/>
+        <location filename="../lxqtpowermanager.cpp" line="118"/>
         <source>Hibernate</source>
         <translation>Hibernasi</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="124"/>
+        <location filename="../lxqtpowermanager.cpp" line="125"/>
         <source>Suspend</source>
         <translation>Suspensi</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="131"/>
+        <location filename="../lxqtpowermanager.cpp" line="132"/>
         <source>Reboot</source>
         <translation>Muat ulang</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="138"/>
+        <location filename="../lxqtpowermanager.cpp" line="139"/>
         <source>Shutdown</source>
         <translation>Matikan</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="145"/>
+        <location filename="../lxqtpowermanager.cpp" line="146"/>
         <source>Logout</source>
         <translation>Keluar</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="157"/>
+        <location filename="../lxqtpowermanager.cpp" line="158"/>
         <source>LXQt Session Suspend</source>
         <translation>Suspensi Sesi LXQt</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="158"/>
+        <location filename="../lxqtpowermanager.cpp" line="159"/>
         <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
         <translation>Apakah Anda ingin mensuspensi komputer Anda?&lt;p&gt;Suspensi komputer ke kondisi daya rendah. Kondisi sistem tidak disimpan jika daya hilang.</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="167"/>
+        <location filename="../lxqtpowermanager.cpp" line="168"/>
         <source>LXQt Session Hibernate</source>
         <translation>Hibernasi Sesi LXQt</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="168"/>
+        <location filename="../lxqtpowermanager.cpp" line="169"/>
         <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
         <translation>Apakah Anda ingin menghibernasi komputer Anda?&lt;p&gt;Hibernasi kompeter ke kondisi daya rendah. Kondisi sistem akan disimpan jika daya hilang.</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="177"/>
+        <location filename="../lxqtpowermanager.cpp" line="178"/>
         <source>LXQt Session Reboot</source>
         <translation>Jalankan Ulang Sesi LXQt</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="178"/>
+        <location filename="../lxqtpowermanager.cpp" line="179"/>
         <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
         <translation>Apakah Anda ingin menjalankan ulang komputer? Semua pekerjaan yang belum disimpan akan hilang....</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="187"/>
+        <location filename="../lxqtpowermanager.cpp" line="188"/>
         <source>LXQt Session Shutdown</source>
         <translation>Matikan Sesi LXQt</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="188"/>
+        <location filename="../lxqtpowermanager.cpp" line="189"/>
         <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
         <translation>Apakah Anda ingin mematikan komputer? Semua pekerjaan yang belum disimpan akan hilang....</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="197"/>
+        <location filename="../lxqtpowermanager.cpp" line="198"/>
         <source>LXQt Session Logout</source>
         <translation>Keluar Sesi LXQt</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="198"/>
+        <location filename="../lxqtpowermanager.cpp" line="199"/>
         <source>Do you want to really logout? All unsaved work will be lost...</source>
         <translation>Apakah Anda ingin keluar? Semua pekerjaan yang belum disimpan akan hilang...</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="206"/>
-        <location filename="../lxqtpowermanager.cpp" line="211"/>
+        <location filename="../lxqtpowermanager.cpp" line="207"/>
+        <location filename="../lxqtpowermanager.cpp" line="212"/>
         <source>LXQt Power Manager Error</source>
         <translation>Kesalahan Manajer Daya LXQt</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="206"/>
+        <location filename="../lxqtpowermanager.cpp" line="207"/>
         <source>Hibernate failed.</source>
         <translation>Hibernasi gagal.</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="211"/>
+        <location filename="../lxqtpowermanager.cpp" line="212"/>
         <source>Suspend failed.</source>
         <translation>Suspensi gagal.</translation>
     </message>
@@ -127,7 +127,17 @@
 <context>
     <name>LXQt::ScreenSaver</name>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="236"/>
+        <location filename="../lxqtscreensaver.cpp" line="161"/>
+        <source>Failed to run  &quot;%1&quot;. Ensure you have a locker/screensaver compatible with xdg-screensaver installed and running.</source>
+        <translation>Gagal untuk menjalankan  &quot;%1&quot;. Pastikan Anda memiliki sebuah pengunci/screensaver yang kompatibel dengan xdg-screensaver yang terinstall dan dijalankan.</translation>
+    </message>
+    <message>
+        <location filename="../lxqtscreensaver.cpp" line="165"/>
+        <source>Failed to run  &quot;%1&quot;. Ensure the specified locker/screensaver is installed and running.</source>
+        <translation>Gagal untuk menjalankan  &quot;%1&quot;. Pastikan pengunci/screensaver yang ditentukan telah terpasang dan bekerja.</translation>
+    </message>
+    <message>
+        <location filename="../lxqtscreensaver.cpp" line="243"/>
         <source>Lock Screen</source>
         <translation>Kunci Layar</translation>
     </message>
@@ -136,33 +146,6 @@
         <source>Screen Saver Error</source>
         <translation>Kesalahan Screen Saver</translation>
     </message>
-    <message>
-        <location filename="../lxqtscreensaver.cpp" line="162"/>
-        <location filename="../lxqtscreensaver.cpp" line="168"/>
-        <location filename="../lxqtscreensaver.cpp" line="175"/>
-        <source>Screen Saver Activation Error</source>
-        <translation>Kesalahan Aktivasi Screen Saver</translation>
-    </message>
-    <message>
-        <location filename="../lxqtscreensaver.cpp" line="176"/>
-        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
-        <translation>Terjadi kesalahan saat menjalankan screensaver. Kesalahan tidak diketahui - nilai pengembalian tidak terdokumentasi dari xdg-screensaver: %1.</translation>
-    </message>
-    <message>
-        <location filename="../lxqtscreensaver.cpp" line="157"/>
-        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
-        <translation>Terjadi kesalahan saat menjalankan screensaver. Kesalahan sintaks di argumen xdg-screensaver.</translation>
-    </message>
-    <message>
-        <location filename="../lxqtscreensaver.cpp" line="163"/>
-        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
-        <translation>Terjadi kesalahan saat menjalankan screensaver. Pastikan xscreensaver telah terpasang dan berjalan.</translation>
-    </message>
-    <message>
-        <location filename="../lxqtscreensaver.cpp" line="169"/>
-        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
-        <translation>Terjadi kesalahan saat menjalankan screensaver. Aksi &apos;activate&apos; gagal. Pastikan xscreensaver telah terpasang dan berjalan.</translation>
-    </message>
 </context>
 <context>
     <name>QCoreApplication</name>
