@@ -12,14 +12,14 @@
 <context>
     <name>LXQt::MessageBox</name>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="74"/>
+        <location filename="../lxqtpowermanager.cpp" line="75"/>
         <source>LXQt Power Manager Error</source>
-        <translation>LXQt電源管理エラー</translation>
+        <translation>LXQt 電源管理エラー</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="74"/>
+        <location filename="../lxqtpowermanager.cpp" line="75"/>
         <source>Hibernate failed.</source>
-        <translation>ハイバーネーションを失敗しました。</translation>
+        <translation>ハイバネートを失敗しました。</translation>
     </message>
 </context>
 <context>
@@ -33,94 +33,93 @@
 <context>
     <name>LXQt::PowerManager</name>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="117"/>
+        <location filename="../lxqtpowermanager.cpp" line="118"/>
         <source>Hibernate</source>
-        <translation>休止</translation>
+        <translation>ハイバネート</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="124"/>
+        <location filename="../lxqtpowermanager.cpp" line="125"/>
         <source>Suspend</source>
         <translation>サスペンド</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="131"/>
+        <location filename="../lxqtpowermanager.cpp" line="132"/>
         <source>Reboot</source>
         <translation>再起動</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="138"/>
+        <location filename="../lxqtpowermanager.cpp" line="139"/>
         <source>Shutdown</source>
         <translation>シャットダウン</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="145"/>
+        <location filename="../lxqtpowermanager.cpp" line="146"/>
         <source>Logout</source>
         <translation>ログアウト</translation>
     </message>
-    <message>
-        <location filename="../lxqtpowermanager.cpp" line="157"/>
-        <source>LXQt Session Suspend</source>
-        <translation>LXQtセッションのサスペンド</translation>
-    </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="158"/>
-        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
-        <translation>本当にコンピュータをサスペンドしますか？&lt;P&gt;コンピュータを低消費電力状態にサスペンドします。電源が失われた場合にはシステムの状態は保持されません。</translation>
+        <source>LXQt Session Suspend</source>
+        <translation>LXQt セッションのサスペンド</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="167"/>
-        <source>LXQt Session Hibernate</source>
-        <translation>LXQtセッションの休止</translation>
+        <location filename="../lxqtpowermanager.cpp" line="159"/>
+        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
+        <translation>本当にコンピューターをサスペンドしますか？&lt;P&gt;コンピューターを低消費電力状態にサスペンドします。電源が失われた場合にはシステムの状態は保持されません。</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="168"/>
-        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
-        <translation>本当にコンピュータを休止状態にしますか？&lt;P&gt;コンピュータを
-低消費電力状態で休止します。電源が失われた場合でもシステムの状態は保持されます。</translation>
+        <source>LXQt Session Hibernate</source>
+        <translation>LXQt セッションのハイバネート</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="177"/>
-        <source>LXQt Session Reboot</source>
-        <translation>LXQtセッションの再起動</translation>
+        <location filename="../lxqtpowermanager.cpp" line="169"/>
+        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
+        <translation>本当にコンピューターをハイバネートにしますか？&lt;P&gt;コンピューターを低消費電力状態で休止します。電源が失われた場合でもシステムの状態は保持されます。</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="178"/>
-        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
-        <translation>本当にコンピュータを再起動しますか？保存されていない作業はすべて失われます...</translation>
+        <source>LXQt Session Reboot</source>
+        <translation>LXQt セッションの再起動</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="187"/>
-        <source>LXQt Session Shutdown</source>
-        <translation>LXQtセッションのシャットダウン</translation>
+        <location filename="../lxqtpowermanager.cpp" line="179"/>
+        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
+        <translation>本当にコンピューターを再起動しますか？ 保存されていない作業はすべて失われます...</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="188"/>
-        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
-        <translation>本当にコンピュータをオフにしたいですか？保存されていないすべての作業は失われます...</translation>
+        <source>LXQt Session Shutdown</source>
+        <translation>LXQt セッションのシャットダウン</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="197"/>
-        <source>LXQt Session Logout</source>
-        <translation>LXQtセッションのログアウト</translation>
+        <location filename="../lxqtpowermanager.cpp" line="189"/>
+        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
+        <translation>本当にコンピューターをオフしますか？ 保存されていないすべての作業は失われます...</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="198"/>
+        <source>LXQt Session Logout</source>
+        <translation>LXQt セッションのログアウト</translation>
+    </message>
+    <message>
+        <location filename="../lxqtpowermanager.cpp" line="199"/>
         <source>Do you want to really logout? All unsaved work will be lost...</source>
-        <translation>本当にログアウトしたいですか？保存されていないすべての作業は失われます...</translation>
+        <translation>本当にログアウトしますか？ 保存されていないすべての作業は失われます...</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="206"/>
-        <location filename="../lxqtpowermanager.cpp" line="211"/>
+        <location filename="../lxqtpowermanager.cpp" line="207"/>
+        <location filename="../lxqtpowermanager.cpp" line="212"/>
         <source>LXQt Power Manager Error</source>
-        <translation>LXQt電源管理エラー</translation>
+        <translation>LXQt 電源管理エラー</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="206"/>
+        <location filename="../lxqtpowermanager.cpp" line="207"/>
         <source>Hibernate failed.</source>
-        <translation>ハイバーネーションを失敗しました。</translation>
+        <translation>ハイバネートを失敗しました。</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="211"/>
+        <location filename="../lxqtpowermanager.cpp" line="212"/>
         <source>Suspend failed.</source>
         <translation>サスペンドを失敗しました。</translation>
     </message>
@@ -128,49 +127,32 @@
 <context>
     <name>LXQt::ScreenSaver</name>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="236"/>
+        <location filename="../lxqtscreensaver.cpp" line="161"/>
+        <source>Failed to run  &quot;%1&quot;. Ensure you have a locker/screensaver compatible with xdg-screensaver installed and running.</source>
+        <translation>&quot;%1&quot; の実行に失敗しました。 xdg-screensaver 互換のロッカーまたはスクリーンセーバーがインストールされ実行しているか確認して下さい。</translation>
+    </message>
+    <message>
+        <location filename="../lxqtscreensaver.cpp" line="165"/>
+        <source>Failed to run  &quot;%1&quot;. Ensure the specified locker/screensaver is installed and running.</source>
+        <translation>&quot;%1&quot; の実行に失敗しました。指定したロッカーまたはスクリーンセーバーがインストールされ実行しているか確認して下さい。</translation>
+    </message>
+    <message>
+        <location filename="../lxqtscreensaver.cpp" line="243"/>
         <source>Lock Screen</source>
-        <translation>スクリーンをロック</translation>
+        <translation>画面のロック</translation>
     </message>
     <message>
         <location filename="../lxqtscreensaver.cpp" line="156"/>
         <source>Screen Saver Error</source>
         <translation>スクリーンセーバーのエラー</translation>
     </message>
-    <message>
-        <location filename="../lxqtscreensaver.cpp" line="162"/>
-        <location filename="../lxqtscreensaver.cpp" line="168"/>
-        <location filename="../lxqtscreensaver.cpp" line="175"/>
-        <source>Screen Saver Activation Error</source>
-        <translation>スクリーンセーバー起動エラー</translation>
-    </message>
-    <message>
-        <location filename="../lxqtscreensaver.cpp" line="176"/>
-        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
-        <translation>スクリーンセーバーの起動時にエラーが発生しました。未知のエラー - undocumented return value from xdg-screensaver: %1.</translation>
-    </message>
-    <message>
-        <location filename="../lxqtscreensaver.cpp" line="157"/>
-        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
-        <translation>スクリーンセーバーの起動時にエラーが発生しました。xdg-スクリーンセーバーの引数に構文エラーがあります。</translation>
-    </message>
-    <message>
-        <location filename="../lxqtscreensaver.cpp" line="163"/>
-        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
-        <translation>スクリーンセーバーの起動時にエラーが発生しました。xscreensaverのインストールと実行を確認してください。</translation>
-    </message>
-    <message>
-        <location filename="../lxqtscreensaver.cpp" line="169"/>
-        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
-        <translation>スクリーンセーバーの起動時にエラーが発生しました。&apos;Activate&apos;アクションが失敗しました。xscreensaverのインストールと実行を確認してください。</translation>
-    </message>
 </context>
 <context>
     <name>QCoreApplication</name>
     <message>
         <location filename="../configdialog/lxqtconfigdialogcmdlineoptions.cpp" line="49"/>
         <source>Choose the page to be shown.</source>
-        <translation type="unfinished"></translation>
+        <translation>表示するページを選択してください。</translation>
     </message>
 </context>
 <context>
@@ -185,13 +167,13 @@
         <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
         <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
         <source>QDBusInterface is invalid</source>
-        <translation>QDbusInterfaceが無効です</translation>
+        <translation>QDbusInterface が無効です</translation>
     </message>
     <message>
         <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
         <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
         <source>Power Manager Error (D-BUS call)</source>
-        <translation>電源マネージャエラー(D-BUSコール)</translation>
+        <translation>電源管理エラー(D-BUS コール)</translation>
     </message>
 </context>
 </TS>
