@@ -12,12 +12,12 @@
 <context>
     <name>LXQt::MessageBox</name>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="74"/>
+        <location filename="../lxqtpowermanager.cpp" line="75"/>
         <source>LXQt Power Manager Error</source>
         <translation>LXQT Greska sa Upravljacem Napajanja</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="74"/>
+        <location filename="../lxqtpowermanager.cpp" line="75"/>
         <source>Hibernate failed.</source>
         <translation>Hibernacija je neuspesna.</translation>
     </message>
@@ -33,93 +33,93 @@
 <context>
     <name>LXQt::PowerManager</name>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="117"/>
+        <location filename="../lxqtpowermanager.cpp" line="118"/>
         <source>Hibernate</source>
-        <translation type="unfinished"></translation>
+        <translation>Hibernacija</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="124"/>
+        <location filename="../lxqtpowermanager.cpp" line="125"/>
         <source>Suspend</source>
-        <translation type="unfinished"></translation>
+        <translation>Obustavi</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="131"/>
+        <location filename="../lxqtpowermanager.cpp" line="132"/>
         <source>Reboot</source>
-        <translation type="unfinished"></translation>
+        <translation>Ponovo Pokretanje</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="138"/>
+        <location filename="../lxqtpowermanager.cpp" line="139"/>
         <source>Shutdown</source>
-        <translation type="unfinished"></translation>
+        <translation>Ugasi</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="145"/>
+        <location filename="../lxqtpowermanager.cpp" line="146"/>
         <source>Logout</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../lxqtpowermanager.cpp" line="157"/>
-        <source>LXQt Session Suspend</source>
-        <translation type="unfinished"></translation>
+        <translation>Odjavi se</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="158"/>
-        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
-        <translation type="unfinished"></translation>
+        <source>LXQt Session Suspend</source>
+        <translation>LXQt sesija obustavljena</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="167"/>
-        <source>LXQt Session Hibernate</source>
-        <translation type="unfinished"></translation>
+        <location filename="../lxqtpowermanager.cpp" line="159"/>
+        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
+        <translation>Da li stvarno želite da obustavite računar?&lt;p&gt;Obustavlja računar kada je stanje male energije. Sistemski status nije sačuvan kada nema struje.</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="168"/>
-        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
-        <translation type="unfinished"></translation>
+        <source>LXQt Session Hibernate</source>
+        <translation>LXQt Sesija Hibernacija</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="177"/>
-        <source>LXQt Session Reboot</source>
-        <translation type="unfinished"></translation>
+        <location filename="../lxqtpowermanager.cpp" line="169"/>
+        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
+        <translation>Želite li zaista hibernirati svoj računar?&lt;p&gt;Hibernira računar u stanje male potrošnje. Stanje sistema je sačuvano ako nestane struja.</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="178"/>
-        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
-        <translation type="unfinished"></translation>
+        <source>LXQt Session Reboot</source>
+        <translation>Ponovno pokretanje sesije LXQt</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="187"/>
-        <source>LXQt Session Shutdown</source>
-        <translation type="unfinished"></translation>
+        <location filename="../lxqtpowermanager.cpp" line="179"/>
+        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
+        <translation>Da li stvarno želite ponovo pokrenuti vas računar? Svi nespremljeni radovi će se izgubiti...</translation>
     </message>
     <message>
         <location filename="../lxqtpowermanager.cpp" line="188"/>
+        <source>LXQt Session Shutdown</source>
+        <translation>LXQt ugasivanje sesije</translation>
+    </message>
+    <message>
+        <location filename="../lxqtpowermanager.cpp" line="189"/>
         <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="197"/>
+        <location filename="../lxqtpowermanager.cpp" line="198"/>
         <source>LXQt Session Logout</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="198"/>
+        <location filename="../lxqtpowermanager.cpp" line="199"/>
         <source>Do you want to really logout? All unsaved work will be lost...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="206"/>
-        <location filename="../lxqtpowermanager.cpp" line="211"/>
+        <location filename="../lxqtpowermanager.cpp" line="207"/>
+        <location filename="../lxqtpowermanager.cpp" line="212"/>
         <source>LXQt Power Manager Error</source>
         <translation type="unfinished">LXQT Greska sa Upravljacem Napajanja</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="206"/>
+        <location filename="../lxqtpowermanager.cpp" line="207"/>
         <source>Hibernate failed.</source>
         <translation type="unfinished">Hibernacija je neuspesna.</translation>
     </message>
     <message>
-        <location filename="../lxqtpowermanager.cpp" line="211"/>
+        <location filename="../lxqtpowermanager.cpp" line="212"/>
         <source>Suspend failed.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -127,7 +127,17 @@
 <context>
     <name>LXQt::ScreenSaver</name>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="236"/>
+        <location filename="../lxqtscreensaver.cpp" line="161"/>
+        <source>Failed to run  &quot;%1&quot;. Ensure you have a locker/screensaver compatible with xdg-screensaver installed and running.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtscreensaver.cpp" line="165"/>
+        <source>Failed to run  &quot;%1&quot;. Ensure the specified locker/screensaver is installed and running.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtscreensaver.cpp" line="243"/>
         <source>Lock Screen</source>
         <translation type="unfinished"></translation>
     </message>
@@ -136,33 +146,6 @@
         <source>Screen Saver Error</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../lxqtscreensaver.cpp" line="162"/>
-        <location filename="../lxqtscreensaver.cpp" line="168"/>
-        <location filename="../lxqtscreensaver.cpp" line="175"/>
-        <source>Screen Saver Activation Error</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../lxqtscreensaver.cpp" line="176"/>
-        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../lxqtscreensaver.cpp" line="157"/>
-        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../lxqtscreensaver.cpp" line="163"/>
-        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../lxqtscreensaver.cpp" line="169"/>
-        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>QCoreApplication</name>
